# PTIC

PTIC tool for texts classification, uses following statistical model:

* point-wise mutual information for word and a class
* tf-idf (term frequency-inverse document frequency) for word in a text

## Installation
### From PyPi

```bash
pip install ptic
```

### From source

```bash
pip install git+https://github.com/sysbio-vo/ptic.git
```
